import { useRef, useCallback } from 'react';

function useLatestAsyncCall(fn) {
  const latestValue = useRef();
  const wrappedFn = useCallback(
    (value) => {
      latestValue.current = value;
      return new Promise((resolve, reject) => {
        fn(value).then((result) => {
          if (latestValue.current === value) {
            resolve(result);
          } else {
            reject(new StaleResultError());
          }
        });
      });
    },
    [fn]
  );
  return wrappedFn;
}
class StaleResultError extends Error {
  constructor() {
    super("This result is stale and is discarded");
    this.name = "StaleResultError";
    Object.setPrototypeOf(this, new.target.prototype);
  }
}

export { StaleResultError, useLatestAsyncCall };
//# sourceMappingURL=useLatestAsyncCall.js.map
